@@ -7,12 +7,11 @@
 // +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
 // [[Rcpp::depends(RcppArmadillo)]]
-#include <RcppArmadillo.h>
-#include "util.h"
+#include "RLumCarlo.h"
 using namespace Rcpp;
 
 // [[Rcpp::export("MC_C_ISO_DELOC")]]
-List MC_C_ISO_DELOC(arma::vec times, double N_e, double n_filled, double R, double E, double s, double T) {
+List MC_C_ISO_DELOC(arma::vec times, int N_e, int n_filled, double R, double E, double s, double T) {
   //N >> N_e total: concentration of traps [cm^-3]
   //n >> n_filled: concentration of filled traps [cm^-3]
   //t >> times: refers basically to the temperature
@@ -24,9 +23,6 @@ List MC_C_ISO_DELOC(arma::vec times, double N_e, double n_filled, double R, doub
   //determine delta_t which allows to have delta t != 1
   double delta_t = calc_deltat(times);
 
-   // set Boltzmann's constant
-  double k_B = 8.617*pow(10.0,-5.0);
-
   // set output matrices
   NumericMatrix signal (times.size(), 1);
   NumericMatrix remaining_e (times.size(), 1);
@@ -54,7 +50,7 @@ List MC_C_ISO_DELOC(arma::vec times, double N_e, double n_filled, double R, doub
 
           //calculate signal and remaining filled (here we have n_filled^2 before
           //we have this per particle)
-          signal(t,0) = P * (pow(n_filled,2.0) / (N_e * R + n_filled * (1 - R)));
+          signal(t,0) = P * (pow(static_cast<double>(n_filled),2.0) / (N_e * R + n_filled * (1 - R)));
           remaining_e(t,0) = n_filled;
 
           if (n_filled == 0)
